@@ -1,4 +1,8 @@
-#!/usr/pkg/bin/perl
+package Mail::DKIM::Signature;
+use strict;
+use warnings;
+our $VERSION = '1.20240619'; # VERSION
+# ABSTRACT: represents a DKIM-Signature header
 
 # Copyright 2005-2007 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
@@ -7,39 +11,14 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-use strict;
-use warnings;
-
 use Mail::DKIM::PublicKey;
 use Mail::DKIM::Algorithm::rsa_sha1;
 use Mail::DKIM::Algorithm::rsa_sha256;
+use Mail::DKIM::Algorithm::ed25519_sha256;
 
-package Mail::DKIM::Signature;
 use base 'Mail::DKIM::KeyValueList';
 use Carp;
 
-=head1 NAME
-
-Mail::DKIM::Signature - represents a DKIM-Signature header
-
-=head1 CONSTRUCTORS
-
-=head2 new() - create a new signature from parameters
-
-  my $signature = Mail::DKIM::Signature->new(
-                      [ Algorithm => 'rsa-sha1', ]
-                      [ Signature => $base64, ]
-                      [ Method => 'relaxed', ]
-                      [ Domain => 'example.org', ]
-                      [ Identity => 'user@example.org', ]
-                      [ Headers => 'from:subject:date:message-id', ]
-                      [ Query => 'dns', ]
-                      [ Selector => 'alpha', ]
-                      [ Timestamp => time(), ]
-                      [ Expiration => time() + 86400, ]
-                  );
-
-=cut
 
 sub new {
     my $class = shift;
@@ -58,26 +37,11 @@ sub new {
     $self->identity( $prms{'Identity'} )     if exists $prms{'Identity'};
     $self->timestamp( $prms{'Timestamp'} )   if defined $prms{'Timestamp'};
     $self->expiration( $prms{'Expiration'} ) if defined $prms{'Expiration'};
+    $self->tags( $prms{'Tags'} ) if defined $prms{'Tags'};
     $self->key( $prms{'Key'} )               if defined $prms{'Key'};
-
     return $self;
 }
 
-=head2 parse() - create a new signature from a DKIM-Signature header
-
-  my $sig = Mail::DKIM::Signature->parse(
-                  'DKIM-Signature: a=rsa-sha1; b=yluiJ7+0=; c=relaxed'
-            );
-
-Constructs a signature by parsing the provided DKIM-Signature header
-content. You do not have to include the header name (i.e. "DKIM-Signature:")
-but it is recommended, so the header name can be preserved and returned
-the same way in as_string().
-
-Note: The input to this constructor is in the same format as the output
-of the as_string method.
-
-=cut
 
 sub parse {
     my $class = shift;
@@ -102,9 +66,6 @@ sub parse {
     return $self;
 }
 
-=head1 METHODS
-
-=cut
 
 # deprecated
 sub wantheader {
@@ -122,14 +83,6 @@ sub wantheader {
     return;
 }
 
-=head2 algorithm() - get or set the algorithm (a=) field
-
-The algorithm used to generate the signature. Should be either "rsa-sha1",
-an RSA-signed SHA-1 digest, or "rsa-sha256", an RSA-signed SHA-256 digest.
-
-See also hash_algorithm().
-
-=cut
 
 sub algorithm {
     my $self = shift;
@@ -142,18 +95,6 @@ sub algorithm {
     return defined $a ? lc $a : undef;
 }
 
-=head2 as_string() - the signature header as a string
-
-  print $signature->as_string . "\n";
-
-outputs
-
-  DKIM-Signature: a=rsa-sha1; b=yluiJ7+0=; c=relaxed
-
-As shown in the example, the as_string method can be used to generate
-the DKIM-Signature that gets prepended to a signed message.
-
-=cut
 
 sub as_string {
     my $self = shift;
@@ -169,19 +110,6 @@ sub as_string_debug {
       . join( ';', map { '>' . $_->{raw} . '<' } @{ $self->{tags} } );
 }
 
-=head2 as_string_without_data() - signature without the signature data
-
-  print $signature->as_string_without_data . "\n";
-
-outputs
-
-  DKIM-Signature: a=rsa-sha1; b=; c=relaxed
-
-This is similar to the as_string() method, but it always excludes the "data"
-part. This is used by the DKIM canonicalization methods, which require
-incorporating this part of the signature into the signed message.
-
-=cut
 
 sub as_string_without_data {
     my $self = shift;
@@ -193,19 +121,6 @@ sub as_string_without_data {
     return $alt->as_string;
 }
 
-=head2 body_count() - get or set the body count (l=) field
-
-  my $i = $signature->body_count;
-
-Informs the verifier of the number of bytes in the body of the email
-included in the cryptographic hash, starting from 0 immediately
-following the CRLF preceding the body. Also known as the l= tag.
-
-When creating a signature, this tag may be either omitted, or set after
-the selected canonicalization system has received the entire message
-body (but before it canonicalizes the DKIM-Signature).
-
-=cut
 
 sub body_count {
     my $self = shift;
@@ -217,16 +132,6 @@ sub body_count {
     return $self->get_tag('l');
 }
 
-=head2 body_hash() - get or set the body hash (bh=) field
-
-  my $bh = $signature->body_hash;
-
-The hash of the body part of the message. Whitespace is ignored in this
-value. This tag is required.
-
-When accessing this value, whitespace is stripped from the tag for you.
-
-=cut
 
 sub body_hash {
     my $self = shift;
@@ -242,21 +147,6 @@ sub body_hash {
     return $result;
 }
 
-=head2 canonicalization() - get or set the canonicalization (c=) field
-
-  $signature->canonicalization('relaxed', 'simple');
-
-  ($header, $body) = $signature->canonicalization;
-
-Message canonicalization (default is "simple/simple"). This informs the
-verifier of the type of canonicalization used to prepare the message for
-signing.
-
-In scalar context, this returns header/body canonicalization as a single
-string separated by /. In list context, it returns a two element array,
-containing first the header canonicalization, then the body.
-
-=cut
 
 sub canonicalization {
     my $self = shift;
@@ -356,15 +246,6 @@ sub check_version {
     return 1;
 }
 
-=head2 data() - get or set the signature data (b=) field
-
-  my $base64 = $signature->data;
-  $signature->data($base64);
-
-The signature data. Whitespace is automatically stripped from the
-returned value. The data is Base64-encoded.
-
-=cut
 
 sub data {
     my $self = shift;
@@ -420,19 +301,6 @@ sub prefix {
     return $class->DEFAULT_PREFIX();
 }
 
-=head2 domain() - get or set the domain (d=) field
-
-  my $d = $signature->domain;          # gets the domain value
-  $signature->domain('example.org');   # sets the domain value
-
-The domain of the signing entity, as specified in the signature.
-This is the domain that will be queried for the public key.
-
-If using an "internationalized domain name", the domain name must be
-converted to ASCII (following section 4.1 of RFC 3490) before passing
-it to this method.
-
-=cut
 
 sub domain {
     my $self = shift;
@@ -445,14 +313,6 @@ sub domain {
     return defined $d ? lc $d : undef;
 }
 
-=head2 expiration() - get or set the signature expiration (x=) field
-
-Signature expiration (default is undef, meaning no expiration).
-The signature expiration, if defined, is an unsigned integer identifying
-the standard Unix seconds-since-1970 time when the signature will
-expire.
-
-=cut
 
 sub expiration {
     my $self = shift;
@@ -463,6 +323,17 @@ sub expiration {
     return $self->get_tag('x');
 }
 
+sub tags {
+    my $self = shift;
+    my $tags = shift;
+
+    for my $tag (sort keys %$tags) {
+      $self->set_tag( $tag, $tags->{$tag} );
+    }
+    (@_)
+
+}
+
 # allows the type of signature to determine what "algorithm" gets used
 sub get_algorithm_class {
     my $self = shift;
@@ -472,6 +343,7 @@ sub get_algorithm_class {
     my $class =
         $algorithm eq 'rsa-sha1'   ? 'Mail::DKIM::Algorithm::rsa_sha1'
       : $algorithm eq 'rsa-sha256' ? 'Mail::DKIM::Algorithm::rsa_sha256'
+      : $algorithm eq 'ed25519-sha256' ? 'Mail::DKIM::Algorithm::ed25519_sha256'
       :                              undef;
     return $class;
 }
@@ -522,19 +394,6 @@ sub _refetch_public_key {
     $self->fetch_public_key;
 }
 
-=head2 get_public_key() - fetches the public key referenced by this signature
-
-  my $pubkey = $signature->get_public_key;
-
-Public key to fetch is determined by the protocol, selector, and domain
-fields.
-
-This method caches the result of the fetch, so subsequent calls will not
-require additional DNS queries.
-
-This method will C<die> if an error occurs.
-
-=cut
 
 sub get_public_key {
     my $self = shift;
@@ -559,31 +418,6 @@ sub get_public_key {
     }
 }
 
-=head2 get_tag() - access the raw value of a tag in this signature
-
-  my $raw_identity = $signature->get_tag('i');
-
-Use this method to access a tag not already supported by Mail::DKIM,
-or if you want to bypass decoding of the value by Mail::DKIM.
-
-For example, the raw i= (identity) tag is encoded in quoted-printable
-form. If you use the identity() method, Mail::DKIM will decode from
-quoted-printable before returning the value. But if you use
-get_tag('i'), you can access the encoded quoted-printable form of
-the value.
-
-=head2 hash_algorithm() - access the hash algorithm specified in this signature
-
-  my $hash = $signature->hash_algorithm;
-
-Determines what hashing algorithm is used as part of the signature's
-specified algorithm.
-
-For algorithm "rsa-sha1", the hash algorithm is "sha1". Likewise, for
-algorithm "rsa-sha256", the hash algorithm is "sha256". If the algorithm
-is not recognized, undef is returned.
-
-=cut
 
 sub hash_algorithm {
     my $self      = shift;
@@ -592,25 +426,10 @@ sub hash_algorithm {
     return
         $algorithm eq 'rsa-sha1'   ? 'sha1'
       : $algorithm eq 'rsa-sha256' ? 'sha256'
+      : $algorithm eq 'ed25519-sha256' ? 'sha256'
       :                              undef;
 }
 
-=head2 headerlist() - get or set the signed header fields (h=) field
-
-  $signature->headerlist('a:b:c');
-
-  my $headerlist = $signature->headerlist;
-
-  my @headers = $signature->headerlist;
-
-Signed header fields. A colon-separated list of header field names
-that identify the header fields presented to the signing algorithm.
-
-In scalar context, the list of header field names will be returned
-as a single string, with the names joined together with colons.
-In list context, the header field names will be returned as a list.
-
-=cut
 
 sub headerlist {
     my $self = shift;
@@ -637,30 +456,6 @@ sub headerlist {
     return $h;
 }
 
-=head2 identity() - get or set the signing identity (i=) field
-
-  my $i = $signature->identity;
-
-Identity of the user or agent on behalf of which this message is signed.
-The identity has an optional local part, followed by "@", then a domain
-name. The domain name should be the same as or a subdomain of the
-domain returned by the C<domain> method.
-
-Ideally, the identity should match the identity listed in the From:
-header, or the Sender: header, but this is not required to have a
-valid signature. Whether the identity used is "authorized" to sign
-for the given message is not determined here.
-
-If using an "internationalized domain name", the domain name must be
-converted to ASCII (following section 4.1 of RFC 3490) before passing
-it to this method.
-
-Identity values are encoded in the signature in quoted-printable format.
-Using this method will translate to/from quoted-printable as necessary.
-If you want the raw quoted-printable version of the identity, use
-$signature->get_tag('i').
-
-=cut
 
 sub identity {
     my $self = shift;
@@ -694,21 +489,6 @@ sub identity_matches {
     return lc($addr) eq lc($id);
 }
 
-=head2 key() - get or set the private key object
-
-  my $key = $signature->key;
-
-  $signature->key(Mail::DKIM::PrivateKey->load(File => 'private.key'));
-
-The private key is used for signing messages.
-It is not used for verifying messages.
-
-The key object can be any object that implements the
-L<sign_digest()|Mail::DKIM::PrivateKey/"sign_digest()"> method.
-(Providing your own object can be useful if your actual keys
-are stored out-of-process.)
-
-=cut
 
 sub key {
     my $self = shift;
@@ -719,12 +499,6 @@ sub key {
     return $self->{Key};
 }
 
-=head2 method() - get or set the canonicalization (c=) field
-
-Message canonicalization (default is "simple"). This informs the verifier
-of the type of canonicalization used to prepare the message for signing.
-
-=cut
 
 sub method {
     my $self = shift;
@@ -736,13 +510,6 @@ sub method {
     return ( lc $self->get_tag('c') ) || 'simple';
 }
 
-=head2 protocol() - get or set the query methods (q=) field
-
-A colon-separated list of query methods used to retrieve the public
-key (default is "dns"). Each query method is of the form "type[/options]",
-where the syntax and semantics of the options depends on the type.
-
-=cut
 
 sub protocol {
     my $self = shift;
@@ -759,16 +526,6 @@ sub protocol {
     }
 }
 
-=head2 result() - get or set the verification result
-
-  my $result = $signature->result;
-
-  $signature->result('pass');
-
-  # to set the result with details
-  $signature->result('invalid', 'no public key');
-
-=cut
 
 sub result {
     my $self = shift;
@@ -777,14 +534,6 @@ sub result {
     return $self->{verify_result};
 }
 
-=head2 result_detail() - access the result, plus details if available
-
-  my $detail = $signature->result_detail;
-
-An explanation of possible detail messages can be found in the
-documentation for L<Mail::DKIM::Verifier/result_detail()>.
-
-=cut
 
 sub result_detail {
     my $self = shift;
@@ -796,11 +545,6 @@ sub result_detail {
     return $self->{verify_result};
 }
 
-=head2 selector() - get or set the selector (s=) field
-
-The selector subdivides the namespace for the "d=" (domain) tag.
-
-=cut
 
 sub selector {
     my $self = shift;
@@ -811,17 +555,6 @@ sub selector {
     return $self->get_tag('s');
 }
 
-=head2 prettify() - alters the signature to look "nicer" as an email header
-
-  $signature->prettify;
-
-This method may alter the signature in a way that breaks signatures, so
-it should be done ONLY when the signature is being generated, BEFORE being
-fed to the canonicalization algorithm.
-
-See also prettify_safe(), which will not break signatures.
-
-=cut
 
 sub prettify {
     my $self = shift;
@@ -835,14 +568,6 @@ sub prettify {
     );
 }
 
-=head2 prettify_safe() - same as prettify() but only touches the b= part
-
-  $signature->prettify_safe;
-
-This method will not break the signature, but it only affects the b= part
-of the signature.
-
-=cut
 
 sub prettify_safe {
     my $self = shift;
@@ -856,13 +581,6 @@ sub prettify_safe {
     );
 }
 
-=head2 timestamp() - get or set the signature timestamp (t=) field
-
-Signature timestamp (default is undef, meaning unknown creation time).
-This is the time that the signature was created. The value is an unsigned
-integer identifying the number of standard Unix seconds-since-1970.
-
-=cut
 
 sub timestamp {
     my $self = shift;
@@ -873,12 +591,6 @@ sub timestamp {
     return $self->get_tag('t');
 }
 
-=head2 version() - get or set the DKIM specification version (v=) field
-
-This is the version of the DKIM specification that applies to this
-signature record.
-
-=cut
 
 sub version {
     my $self = shift;
@@ -889,22 +601,349 @@ sub version {
     return $self->get_tag('v');
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Mail::DKIM::Signature - represents a DKIM-Signature header
+
+=head1 VERSION
+
+version 1.20240619
+
+=head1 CONSTRUCTORS
+
+=head2 new() - create a new signature from parameters
+
+  my $signature = Mail::DKIM::Signature->new(
+                      [ Algorithm => 'rsa-sha1', ]
+                      [ Signature => $base64, ]
+                      [ Method => 'relaxed', ]
+                      [ Domain => 'example.org', ]
+                      [ Identity => 'user@example.org', ]
+                      [ Headers => 'from:subject:date:message-id', ]
+                      [ Query => 'dns', ]
+                      [ Selector => 'alpha', ]
+                      [ Timestamp => time(), ]
+                      [ Expiration => time() + 86400, ]
+                  );
+
+=head2 parse() - create a new signature from a DKIM-Signature header
+
+  my $sig = Mail::DKIM::Signature->parse(
+                  'DKIM-Signature: a=rsa-sha1; b=yluiJ7+0=; c=relaxed'
+            );
+
+Constructs a signature by parsing the provided DKIM-Signature header
+content. You do not have to include the header name (i.e. "DKIM-Signature:")
+but it is recommended, so the header name can be preserved and returned
+the same way in as_string().
+
+Note: The input to this constructor is in the same format as the output
+of the as_string method.
+
+=head1 METHODS
+
+=head2 algorithm() - get or set the algorithm (a=) field
+
+The algorithm used to generate the signature. Should be one of the
+following:
+- "rsa-sha1",an RSA-signed SHA-1 digest
+- "rsa-sha256", an RSA-signed SHA-256 digest
+- "ed25519-sha256", an Ed25519-signed SHA-256 digest
+
+See also hash_algorithm().
+
+=head2 as_string() - the signature header as a string
+
+  print $signature->as_string . "\n";
+
+outputs
+
+  DKIM-Signature: a=rsa-sha1; b=yluiJ7+0=; c=relaxed
+
+As shown in the example, the as_string method can be used to generate
+the DKIM-Signature that gets prepended to a signed message.
+
+=head2 as_string_without_data() - signature without the signature data
+
+  print $signature->as_string_without_data . "\n";
+
+outputs
+
+  DKIM-Signature: a=rsa-sha1; b=; c=relaxed
+
+This is similar to the as_string() method, but it always excludes the "data"
+part. This is used by the DKIM canonicalization methods, which require
+incorporating this part of the signature into the signed message.
+
+=head2 body_count() - get or set the body count (l=) field
+
+  my $i = $signature->body_count;
+
+Informs the verifier of the number of bytes in the body of the email
+included in the cryptographic hash, starting from 0 immediately
+following the CRLF preceding the body. Also known as the l= tag.
+
+When creating a signature, this tag may be either omitted, or set after
+the selected canonicalization system has received the entire message
+body (but before it canonicalizes the DKIM-Signature).
+
+=head2 body_hash() - get or set the body hash (bh=) field
+
+  my $bh = $signature->body_hash;
+
+The hash of the body part of the message. Whitespace is ignored in this
+value. This tag is required.
+
+When accessing this value, whitespace is stripped from the tag for you.
+
+=head2 canonicalization() - get or set the canonicalization (c=) field
+
+  $signature->canonicalization('relaxed', 'simple');
+
+  ($header, $body) = $signature->canonicalization;
+
+Message canonicalization (default is "simple/simple"). This informs the
+verifier of the type of canonicalization used to prepare the message for
+signing.
+
+In scalar context, this returns header/body canonicalization as a single
+string separated by /. In list context, it returns a two element array,
+containing first the header canonicalization, then the body.
+
+=head2 data() - get or set the signature data (b=) field
+
+  my $base64 = $signature->data;
+  $signature->data($base64);
+
+The signature data. Whitespace is automatically stripped from the
+returned value. The data is Base64-encoded.
+
+=head2 domain() - get or set the domain (d=) field
+
+  my $d = $signature->domain;          # gets the domain value
+  $signature->domain('example.org');   # sets the domain value
+
+The domain of the signing entity, as specified in the signature.
+This is the domain that will be queried for the public key.
+
+If using an "internationalized domain name", the domain name must be
+converted to ASCII (following section 4.1 of RFC 3490) before passing
+it to this method.
+
+=head2 expiration() - get or set the signature expiration (x=) field
+
+Signature expiration (default is undef, meaning no expiration).
+The signature expiration, if defined, is an unsigned integer identifying
+the standard Unix seconds-since-1970 time when the signature will
+expire.
+
+=head2 get_public_key() - fetches the public key referenced by this signature
+
+  my $pubkey = $signature->get_public_key;
+
+Public key to fetch is determined by the protocol, selector, and domain
+fields.
+
+This method caches the result of the fetch, so subsequent calls will not
+require additional DNS queries.
+
+This method will C<die> if an error occurs.
+
+=head2 get_tag() - access the raw value of a tag in this signature
+
+  my $raw_identity = $signature->get_tag('i');
+
+Use this method to access a tag not already supported by Mail::DKIM,
+or if you want to bypass decoding of the value by Mail::DKIM.
+
+For example, the raw i= (identity) tag is encoded in quoted-printable
+form. If you use the identity() method, Mail::DKIM will decode from
+quoted-printable before returning the value. But if you use
+get_tag('i'), you can access the encoded quoted-printable form of
+the value.
+
+=head2 hash_algorithm() - access the hash algorithm specified in this signature
+
+  my $hash = $signature->hash_algorithm;
+
+Determines what hashing algorithm is used as part of the signature's
+specified algorithm.
+
+For algorithm "rsa-sha1", the hash algorithm is "sha1". Likewise, for
+algorithm "rsa-sha256", the hash algorithm is "sha256". If the algorithm
+is not recognized, undef is returned.
+
+=head2 headerlist() - get or set the signed header fields (h=) field
+
+  $signature->headerlist('a:b:c');
+
+  my $headerlist = $signature->headerlist;
+
+  my @headers = $signature->headerlist;
+
+Signed header fields. A colon-separated list of header field names
+that identify the header fields presented to the signing algorithm.
+
+In scalar context, the list of header field names will be returned
+as a single string, with the names joined together with colons.
+In list context, the header field names will be returned as a list.
+
+=head2 identity() - get or set the signing identity (i=) field
+
+  my $i = $signature->identity;
+
+Identity of the user or agent on behalf of which this message is signed.
+The identity has an optional local part, followed by "@", then a domain
+name. The domain name should be the same as or a subdomain of the
+domain returned by the C<domain> method.
+
+Ideally, the identity should match the identity listed in the From:
+header, or the Sender: header, but this is not required to have a
+valid signature. Whether the identity used is "authorized" to sign
+for the given message is not determined here.
+
+If using an "internationalized domain name", the domain name must be
+converted to ASCII (following section 4.1 of RFC 3490) before passing
+it to this method.
+
+Identity values are encoded in the signature in quoted-printable format.
+Using this method will translate to/from quoted-printable as necessary.
+If you want the raw quoted-printable version of the identity, use
+$signature->get_tag('i').
+
+=head2 key() - get or set the private key object
+
+  my $key = $signature->key;
+
+  $signature->key(Mail::DKIM::PrivateKey->load(File => 'private.key'));
+
+The private key is used for signing messages.
+It is not used for verifying messages.
+
+The key object can be any object that implements the
+L<sign_digest()|Mail::DKIM::PrivateKey/"sign_digest()"> method.
+(Providing your own object can be useful if your actual keys
+are stored out-of-process.)
+
+=head2 method() - get or set the canonicalization (c=) field
+
+Message canonicalization (default is "simple"). This informs the verifier
+of the type of canonicalization used to prepare the message for signing.
+
+=head2 protocol() - get or set the query methods (q=) field
+
+A colon-separated list of query methods used to retrieve the public
+key (default is "dns"). Each query method is of the form "type[/options]",
+where the syntax and semantics of the options depends on the type.
+
+=head2 result() - get or set the verification result
+
+  my $result = $signature->result;
+
+  $signature->result('pass');
+
+  # to set the result with details
+  $signature->result('invalid', 'no public key');
+
+=head2 result_detail() - access the result, plus details if available
+
+  my $detail = $signature->result_detail;
+
+An explanation of possible detail messages can be found in the
+documentation for L<Mail::DKIM::Verifier/result_detail()>.
+
+=head2 selector() - get or set the selector (s=) field
+
+The selector subdivides the namespace for the "d=" (domain) tag.
+
+=head2 prettify() - alters the signature to look "nicer" as an email header
+
+  $signature->prettify;
+
+This method may alter the signature in a way that breaks signatures, so
+it should be done ONLY when the signature is being generated, BEFORE being
+fed to the canonicalization algorithm.
+
+See also prettify_safe(), which will not break signatures.
+
+=head2 prettify_safe() - same as prettify() but only touches the b= part
+
+  $signature->prettify_safe;
+
+This method will not break the signature, but it only affects the b= part
+of the signature.
+
+=head2 timestamp() - get or set the signature timestamp (t=) field
+
+Signature timestamp (default is undef, meaning unknown creation time).
+This is the time that the signature was created. The value is an unsigned
+integer identifying the number of standard Unix seconds-since-1970.
+
+=head2 version() - get or set the DKIM specification version (v=) field
+
+This is the version of the DKIM specification that applies to this
+signature record.
+
 =head1 SEE ALSO
 
 L<Mail::DKIM::DkSignature> for DomainKey-Signature headers
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Jason Long, E<lt>jlong@messiah.eduE<gt>
+=over 4
+
+=item *
+
+Jason Long <jason@long.name>
+
+=item *
+
+Marc Bradshaw <marc@marcbradshaw.net>
+
+=item *
+
+Bron Gondwana <brong@fastmailteam.com> (ARC)
+
+=back
+
+=head1 THANKS
+
+Work on ensuring that this module passes the ARC test suite was
+generously sponsored by Valimail (https://www.valimail.com/)
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+=over 4
+
+=item *
+
+Copyright (C) 2013 by Messiah College
+
+=item *
+
+Copyright (C) 2010 by Jason Long
+
+=item *
+
+Copyright (C) 2017 by Standcore LLC
+
+=item *
+
+Copyright (C) 2020 by FastMail Pty Ltd
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
 =cut
-
-1;
